"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vscode = require("vscode");
const template_html_1 = require("./template.html");
const configurationProvider_1 = require("./configurationProvider");
const issueProvider_1 = require("./issueProvider");
function activate(context) {
    let disposable = vscode.commands.registerCommand('giteaIssues.initRepo', () => {
        initializeIssueTracker();
    });
    context.subscriptions.push(disposable);
    const openIssuesProvider = new issueProvider_1.OpenIssuesProvider();
    const closedIssuesProvider = new issueProvider_1.ClosedIssuesProvider();
    vscode.window.registerTreeDataProvider('open-issues', openIssuesProvider);
    vscode.window.registerTreeDataProvider('closed-issues', closedIssuesProvider);
    // TODO: Implement in next version.
    // vscode.commands.registerCommand('giteaIssues.createIssue', async () => {
    //     const panel = vscode.window.createWebviewPanel('createIssue', 'Create an new Issue', vscode.ViewColumn.Active, {});
    //     panel.webview.html = "";
    // });
    vscode.commands.registerCommand('giteaIssues.openIssue', (issue) => {
        const panel = vscode.window.createWebviewPanel('issue', issue.label, vscode.ViewColumn.Active, {});
        panel.webview.html = template_html_1.showIssueHTML(issue);
    });
    vscode.commands.registerCommand('giteaIssues.refreshIssues', () => {
        openIssuesProvider.refresh();
        closedIssuesProvider.refresh();
    });
}
exports.activate = activate;
function deactivate() { }
exports.deactivate = deactivate;
function initializeIssueTracker() {
    return __awaiter(this, void 0, void 0, function* () {
        if (vscode.workspace.rootPath === undefined) {
            return vscode.window.showErrorMessage("No project opened!");
        }
        let Token, Domain, Owner, Name;
        yield vscode.window.showInputBox({
            placeHolder: "Enter your gitea token here",
        }).then(token => {
            Token = token === undefined ? "" : token;
        });
        yield vscode.window.showInputBox({
            placeHolder: "Domain from your gitea server without 'https://'",
        }).then(domain => {
            Domain = domain === undefined ? "" : domain;
        });
        yield vscode.window.showInputBox({
            placeHolder: "Repository Owner",
        }).then(owner => {
            Owner = owner === undefined ? "" : owner;
        });
        yield vscode.window.showInputBox({
            placeHolder: "Repository Name",
        }).then(name => {
            Name = name === undefined ? "" : name;
        });
        const repoInfo = {
            token: Token,
            domain: Domain,
            repo_owner: Owner,
            repo_name: Name,
        };
        const rpim = new configurationProvider_1.RepositoryInformationManager();
        rpim.saveRepoInformation(vscode.workspace.rootPath, repoInfo);
    });
}
exports.initializeIssueTracker = initializeIssueTracker;
//# sourceMappingURL=extension.js.map